@@ -5,17 +5,10 @@ use 5.006;
 use strict;
 use warnings;
 
+our $VERSION = '0.28';
 
-BEGIN {
-	our $VERSION = '0.27';
-#	if ($] >= 5.014) {
-		require XSLoader;
-		XSLoader::load("Const::XS", $VERSION);
-#	} else {
-#		require Const::XS::PP;
-#		Const::XS::PP->import(qw/all/);
-#	}
-}
+require XSLoader;
+XSLoader::load("Const::XS", $VERSION);
 
 use base qw/Import::Export/;
 
@@ -38,7 +31,7 @@ Const::XS - Facility for creating read-only scalars, arrays, hashes
 
 =head1 VERSION
 
-Version 0.27
+Version 0.28
 
 =cut
 
@@ -76,9 +69,7 @@ Version 0.27
 
 =head1 DESCRIPTION
 
-The Const::XS module facilitates the creation of high-performance read-only variables in Perl. Beginning with Perl version X, Const::XS is able to leverages XS, while older versions revert to a pure Perl fallback.If you would like to use the pure Perl version simply append ::PP to your use statement.
-
-	use Const::XS::PP qw/const/;
+The Const::XS module facilitates the creation of high-performance read-only variables in Perl. It’s implemented in XS/C and delivers a 4x+ performance improvement compared to L<Const::PP>, a pure Perl version of this module that maintains full backward compatibility.
 
 =head1 EXPORTS
 
@@ -142,9 +133,9 @@ The fifth function exported by this module is is_readonly. It will deeply check
 	use Benchmark qw(:all);
 	use Const::Fast;
 	use Const::XS;
+	use Const::PP;
 	use Readonly;
 
-
 	my $r = timethese(5000000, {
 		'Readonly' => sub {
 			Readonly::Scalar my $string => "Hello World";
@@ -156,9 +147,9 @@ The fifth function exported by this module is is_readonly. It will deeply check
 			Readonly::Array my @array => (
 				qw/1 2 3/, $string, \%hash
 			);
-			$string;
-			$hash{a};
-			$array[0];
+			die unless $string eq "Hello World";
+			die unless $hash{a} eq "Hello World";
+			die unless $array[3] eq "Hello World";
 		},
 		'Const::Fast' => sub {
 			Const::Fast::const my $string => "Hello World";
@@ -170,9 +161,23 @@ The fifth function exported by this module is is_readonly. It will deeply check
 			Const::Fast::const my @array => (
 				qw/1 2 3/, $string, \%hash
 			);
-			$string;
-			$hash{a};
-			$array[0];
+			die unless $string eq "Hello World";
+			die unless $hash{a} eq "Hello World";
+			die unless $array[3] eq "Hello World";
+		},
+		'Const::PP' => sub {
+			Const::XS::PP::const my $string => "Hello World";
+			Const::XS::PP::const my %hash => (
+				a => $string,
+				b => $string,
+				c => $string
+			);
+			Const::XS::PP::const my @array => (
+				qw/1 2 3/, $string, \%hash
+			);
+			die unless $string eq "Hello World";
+			die unless $hash{a} eq "Hello World";
+			die unless $array[3] eq "Hello World";
 		},
 		'XS' => sub {
 			Const::XS::const my $string => "Hello World";
@@ -184,9 +189,9 @@ The fifth function exported by this module is is_readonly. It will deeply check
 			Const::XS::const my @array => (
 				qw/1 2 3/, $string, \%hash
 			);
-			$string;
-			$hash{a};
-			$array[0];
+			die unless $string eq "Hello World";
+			die unless $hash{a} eq "Hello World";
+			die unless $array[3] eq "Hello World";
 		}
 	});
 
@@ -194,17 +199,22 @@ The fifth function exported by this module is is_readonly. It will deeply check
 
 ...
 
-	Benchmark: timing 5000000 iterations of Const::Fast, Readonly, XS...
-	Const::Fast: 21.4638 wallclock secs (21.45 usr +  0.00 sys = 21.45 CPU) @ 233100.23/s (n=5000000)
-	  Readonly: 33.0228 wallclock secs (33.00 usr +  0.00 sys = 33.00 CPU) @ 151515.15/s (n=5000000)
-		XS: 3.62688 wallclock secs ( 3.60 usr +  0.03 sys =  3.63 CPU) @ 1377410.47/s (n=5000000)
-			 Rate    Readonly Const::Fast          XS
-	Readonly     151515/s          --        -35%        -89%
-	Const::Fast  233100/s         54%          --        -83%
-	XS          1377410/s        809%        491%          --
+	Const::Fast: 22.5694 wallclock secs (22.53 usr +  0.01 sys = 22.54 CPU) @ 221827.86/s (n=5000000)
+	 Const::PP: 19.7015 wallclock secs (19.66 usr +  0.01 sys = 19.67 CPU) @ 254194.20/s (n=5000000)
+	  Readonly: 34.829 wallclock secs (34.78 usr +  0.01 sys = 34.79 CPU) @ 143719.46/s (n=5000000)
+		XS: 3.92774 wallclock secs ( 3.89 usr +  0.03 sys =  3.92 CPU) @ 1275510.20/s (n=5000000)
+			 Rate    Readonly Const::Fast   Const::PP          XS
+	Readonly     143719/s          --        -35%        -43%        -89%
+	Const::Fast  221828/s         54%          --        -13%        -83%
+	Const::PP    254194/s         77%         15%          --        -80%
+	XS          1275510/s        787%        475%        402%          --
+	
+
 
 =head2 SEE ALSO
 
+L<Const::PP>
+
 L<Const::Fast>
 
 L<Readonly>
